#
# lxc: linux Container library
#
# (C) Copyright IBM Corp. 2007, 2008
#
# Authors:
# Daniel Lezcano <daniel.lezcano at free.fr>
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

# Must use /var/run for runtime_path on older releases or dnsmasq in the
# lxc-net script will not be able to write its pid in /run (selinux denial)
%define _with_runtime_path --with-runtime-path=/var/run

Name: lxc
Version: 1.1.5
Release: 1.0.4%{?dist}
URL: http://linuxcontainers.org
Source: http://linuxcontainers.org/downloads/%{name}-%{version}%{?beta_dot}.tar.gz
Summary: Linux Containers userspace tools
Group: Applications/System
License: LGPL
BuildRoot: %{_tmppath}/%{name}-%{version}-build
Requires: libcap libvirt openssl rsync
Requires: %{name}-libs = %{version}-%{release}
Requires(post): chkconfig
Requires(pre): /usr/sbin/useradd
Requires(postun): /usr/sbin/userdel
# Sparc has nothing to be backwardly compatable with
%ifnarch %{sparc}
Requires: compat-db43
%endif
BuildRequires: libcap libcap-devel docbook-utils automake autoconf libtool

Patch0001: 0001-lxc-add-sparclinux-template.patch
Patch0002: 0002-fix-autodev-on-SELinux-enabled-systems.patch
Patch0003: 0003-disable-autodev-by-default-for-ol6.x-containers.patch
Patch0004: 0004-always-use-latest-repo.patch
Patch0005: 0005-Fix-btrfs-bus-error-on-sparc-on-snapshot-delete.patch
Patch0006: 0006-Timezone-inside-the-container-is-not-the-same-as-the.patch

%define with_python %{?_with_python: 1} %{?!_with_python: 0}
%if %{with_python}
Requires: python3
BuildRequires: python3-devel
%endif

%define with_lua %{?_with_lua: 1} %{?!_with_lua: 0}
%if %{with_lua}
Requires: lua-filesystem
BuildRequires: lua-devel
%endif

%description

The package "%{name}" provides the command lines to create and manage
containers.  It contains a full featured container with the isolation
/ virtualization of the pids, the ipc, the utsname, the mount points,
/proc, /sys, the network and it takes into account the control groups.
It is very light, flexible, and provides a set of tools around the
container like the monitoring with asynchronous events notification,
or the freeze of the container. This package is useful to create
Virtual Private Server, or to run isolated applications like bash or
sshd.

%package        libs
Summary:        runtime library files for %{name}
Group:          System Environment/Libraries

%description    libs
The %{name}-libs package contains libraries for running %{name} applications.

%package devel
Summary: development library for %{name}
Group: Development/Libraries

%description devel
The %{name}-devel package contains header files and library needed for
development of the linux containers.

%prep
%setup
%patch0001 -p1
%patch0002 -p1
%patch0003 -p1
%patch0004 -p1
%patch0005 -p1
%patch0006 -p1
%build
#autoreconf
./autogen.sh
PATH=$PATH:/usr/sbin:/sbin %configure $args \
%if %{with_lua}
  --enable-lua \
%endif
%if %{with_python}
  --enable-python \
%endif
  %{?_with_runtime_path} \
  --disable-rpath \
  --disable-apparmor \
  --with-config-path=/container \
  --with-init-script=sysvinit

make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make install DESTDIR=%{buildroot}
find %{buildroot} -type f -name '*.la' -exec rm -f {} ';'

%clean
rm -rf %{buildroot}

%pre
# Ensure that lxc-dnsmasq uid & gid gets correctly allocated
if getent passwd lxc-dnsmasq >/dev/null 2>&1 ; then : ; else \
 /usr/sbin/useradd -M -r -s /sbin/nologin \
 -c "LXC Networking Service" -d %_localstatedir/%name lxc-dnsmasq 2> /dev/null \
 || exit 1
fi

%post
mkdir -p /container
/sbin/chkconfig --add lxc
/sbin/chkconfig --add lxc-net

# This test should trigger a network configure on a new install.
if [ ! -f %{_sysconfdir}/sysconfig/lxc-net ] || ! grep -q 'USE_LXC_BRIDGE=' %{_sysconfdir}/sysconfig/lxc-net
then
        # Grab a random 10net subnet.  Need to add test logic...
        while [ true ]
        do
                SUBNET=10.$(($RANDOM % 256)).$(($RANDOM % 256))
                if ! ip -4 route ls | grep -q "^$SUBNET"
                then
                        break
                fi
        done

        cat >  %{_sysconfdir}/sysconfig/lxc-net <<EOF
# Leave USE_LXC_BRIDGE as "true" if you want to use lxcbr0 for your
# containers.  Set to "false" if you'll use virbr0 or another existing
# bridge, or mavlan to your host's NIC.
USE_LXC_BRIDGE="true"

# If you change the LXC_BRIDGE to something other than lxcbr0, then
# you will also need to update your /etc/lxc/default.conf as well as the
# configuration (/var/lib/lxc/<container>/config) for any containers
# already created using the default config to reflect the new bridge
# name.
# If you have the dnsmasq daemon installed, you'll also have to update
# /etc/dnsmasq.d/lxc and restart the system wide dnsmasq daemon.
LXC_BRIDGE="lxcbr0"
LXC_ADDR="$SUBNET.1"
LXC_NETMASK="255.255.255.0"
LXC_NETWORK="$SUBNET.0/24"
LXC_DHCP_RANGE="$SUBNET.2,$SUBNET.254"
LXC_DHCP_MAX="253"
# Uncomment the next line if you'd like to use a conf-file for the lxcbr0
# dnsmasq.  For instance, you can use 'dhcp-host=mail1,10.0.3.100' to have
# container 'mail1' always get ip address 10.0.3.100.
#LXC_DHCP_CONFILE=/etc/lxc/dnsmasq.conf

# Uncomment the next line if you want lxcbr0's dnsmasq to resolve the .lxc
# domain.  You can then add "server=/lxc/10.0.3.1' (or your actual $LXC_ADDR)
# to /etc/dnsmasq.conf, after which 'container1.lxc' will resolve on your
# host.
#LXC_DOMAIN="lxc"
EOF
fi

%preun
if [ "$1" = 0 ]
then
  /sbin/chkconfig --del lxc
  /sbin/chkconfig --del lxc-net
fi

%postun
/usr/sbin/userdel lxc-dnsmasq > /dev/null 2>&1 || :

%post   libs -p /sbin/ldconfig
%postun libs -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_bindir}/*
#%{_sbindir}/*
%{_mandir}/man1/lxc*
%{_mandir}/man5/lxc*
%{_mandir}/man7/lxc*
%{_datadir}/doc/*
%{_datadir}/lxc/*
%{_sysconfdir}/bash_completion.d
%config(noreplace) %{_sysconfdir}/lxc/*
%config(noreplace) %{_sysconfdir}/sysconfig/*
%{_sysconfdir}/rc.d/init.d/lxc
%{_sysconfdir}/rc.d/init.d/lxc-net


%files libs
%defattr(-,root,root)
%{_sbindir}/*
%{_libdir}/*.so.*
%{_libdir}/%{name}
%if %{with_lua}
%{_datadir}/lua
%{_libdir}/lua
%endif
%if %{with_python}
%{_libdir}/python*
%endif
%{_localstatedir}/*
%{_libexecdir}/%{name}
%attr(4111,root,root) %{_libexecdir}/%{name}/lxc-user-nic
#%{_libexecdir}/%{name}/lxc-net
#%{_libexecdir}/%{name}/lxc-containers
#%{_libexecdir}/%{name}/lxc-monitord


%files devel
%defattr(-,root,root)
%{_includedir}/%{name}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*

%changelog
* Thu Mar 24 2016 Thomas Tanaka <thomas.tanaka@oracle.com> - 1.1.5-1.0.4
- [Orabug 22960175] LXC: /etc/sysconfig/clock missing in containers

* Thu Jan 14 2016 Thomas Tanaka <thomas.tanaka@oracle.com> - 1.1.5-1.0.3
- Incorporated patches from Dwight Engen for SELINUX problem on 1.1.x
- Fixup the lxc-templates for SPARC to always use the latest
- Fixup the lxc.spec
- [orabug 22534959] Fix btrfs for bus error
- Combined all previous Wim's patch to a single patch

* Fri Dec 25 2015 Philip Copeland <philip.copeland@oracle.com> - 1.1.5-1.0.2
- Wim left out a small change to the configure.ac (added)
- /etc/defaults/lxc doesn't exist, may or may not exist from a previous
  earlier install? who knows., but it isn't there in a brand new install.
  so lets drop it.

* Sun Dec 06 2015 Wim Coekaerts <wim.coekaerts@oracle.com> - 1.1.5-1.0.1
- added sparclinux template files 
- backported setproctitle patch from 1.1.6 to change to info from syserror

* Wed Nov 20 2013 Tianyue Lan <tianyue.lan@oracle.com> - 0.9.0-2.0.6.0.1 
- Added fix_buildfailure_expected_longint.patch for sparc64

* Fri Nov 15 2013 Dwight Engen <dwight.engen@oracle.com> - Version 0.9.0-2.0.6
- orabug 17739144 further disable selinux in ol5 containers
- disable mingetty calling vhangup(2) since this fails when using user_ns
- disable mingetty clearing the console tty so boot messages can be seen
- fix mounting of /proc and /sys to work with user_ns
- fix pam login failures with user_ns

* Thu Oct 17 2013 Dwight Engen <dwight.engen@oracle.com> - Version 0.9.0-2.0.5
- fix ssh into container with SELinux enabled on host
- fix scp into container by installing openssh-clients by default

* Fri Jul 12 2013 Dwight Engen <dwight.engen@oracle.com> - Version 0.9.0-2.0.4
- orabug 16316936 fix sem_open(3) by mounting /dev/shm as tmpfs
- orabug 17042712 fix sshd template
- orabug 17066749 fix hostname in cloned containers

* Thu May  9 2013 Dwight Engen <dwight.engen@oracle.com> - Version 0.9.0-2.0.3
- applied upstream fixes
- oracle build environment for lxc now has newer kernel-headers, which makes
  lxc-attach now work since at build time the the setns syscall introduced
  in kernel 3.7 will be found

* Fri Apr 12 2013 Dwight Engen <dwight.engen@oracle.com> - Version 0.9.0-2.0.2
- applied upstream patches for other minor issues
- orabug 16656944 lxc-clone fails
- The sparc architecture doesn't have or need a compat-db4* requirement
  in the spec-file

* Mon Apr 08 2013 Dwight Engen <dwight.engen@oracle.com> - Version 0.9.0-2.0.1
- update to upstream 0.9.0
- lxc.spec: remove patches that have been upstreamed
- patch back to building docs with docbook-utils instead of docbook2X

* Tue Mar 12 2013 Dwight Engen <dwight.engen@oracle.com> - Version 0.8.0-2.0.9
- move .rpmdb on Debian host
- orabug 16327664 fix cosmetic error on ol5 cp resolv.conf
- orabug 16297950 silence cosmetic "cat /proc/self/attr/current" error

* Thu Feb 14 2013 Dwight Engen <dwight.engen@oracle.com> - Version 0.8.0-2.0.8
- orabug 16324116 handle 5.latest correctly in redo_pkgs
- orabug 16327382 commenting out of "Remounting rootfs" in rc.sysinit

* Wed Feb 13 2013 Dwight Engen <dwight.engen@oracle.com> - Version 0.8.0-2.0.7
- use libvirt for rpm Requires not libvirt-daemon

* Tue Feb 12 2013 Dwight Engen <dwight.engen@oracle.com> - Version 0.8.0-2.0.6
- orabug 16297177 default to same release as host
- orabug 16297404 add libvirt-daemon and compat-db43 as rpm Requires
- orabug 16297950 set selinux labels on devices created by oracle template
- orabug 16302675 don't attempt to remount / (superficial error message)
- orabug 16303282 don't attempt to unmount swap in container halt
- orabug 16304447 bad copy when using oracle templatefs -t option
- orabug 16316699 lxc-ls returning non-container directories

* Fri Feb 08 2013 Dwight Engen <dwight.engen@oracle.com> - Version 0.8.0-2.0.5
- merge all oracle template patches into one, update to latest to handle
  ol4 better and handle some selinux cases
- fix orabug 16296667 due to misapplied patch in lxc-shutdown
- remove distro config /etc/lxc/lxc.conf patch since it is not needed and
  the name is changing in 0.9.0

* Wed Jan 09 2013 Dwight Engen <dwight.engen@oracle.com> - Version 0.8.0-2.0.4
- fix orabug 16010534 prevent insmod, rmmod (git d378aebe)
- fix orabug 16071473 document <Ctrl-a q> to escape lxc-console (git 76848789)
- fix orabug 16090880 lxc-shutdown not working

* Fri Dec 28 2012 Dwight Engen <dwight.engen@oracle.com> - Version 0.8.0-2.0.3
- add fixes for orabugs 15984742, 15989848
- fix creation of busybox based containers

* Fri Dec 14 2012 Dwight Engen <dwight.engen@oracle.com> - Version 0.8.0-2.0.2
- add fixes for orabugs 15984921, 15972116, use with OVM template rootfs
- add support for creating ol4 container from ovm template

* Tue Dec  4 2012 Dwight Engen <dwight.engen@oracle.com> - Version 0.8.0-2.0.1
- Add autoconf, automake to BuildRequires since patch0001 modifies configure.ac,
  and if the build files are not regenerated the Oracle template will not be
  included.
  
* Wed Nov 21 2012 Dwight Engen <dwight.engen@oracle.com> - Version 0.8.0-2
- include oracle template
- set container directory to /container

* Mon Sep 10 2012 Dwight Engen <dwight.engen@oracle.com> - Version 0.8.0
- fix lxc-init moved to libexec
- .pc moved to _libdir
- package template files /usr/share/lxc/templates

* Thu Sep  8 2011 Greg Kurz <gkurz@fr.ibm.com> - Version 0.7.5.1
- fix installed files for rpmbuild
- introduce lxc-libs package

* Fri Jul 23 2010 Daniel Lezcano <dlezcano@fr.ibm.com> - Version 0.7.2
- set attribute for installed files
- fix libraries installation

* Mon Mar 24 2009 Daniel Lezcano <daniel.lezcano@free.fr> - Version 0.6.1
- Removed capability setting, let the user to do that through "lxc-setcap"

* Mon Feb 16 2009 Daniel Lezcano <daniel.lezcano@free.fr> - Version 0.6.0
- Added more capabilities to the executables

* Sun Jan 25 2009 Daniel Lezcano <daniel.lezcano@free.fr> - Version 0.6.0
- Reduced spec file

* Sun Aug 3 2008 Daniel Lezcano <dlezcano@fr.ibm.com> - Version 0.1.0
- Initial RPM release.

# Local variables:
# mode: shell-script
# sh-shell: rpm
# end:
